@@ -1,6 +1,6 @@
 #!/bin/sh
 # savecpu
-# versione 2.0 by m750 at smartphonetab.net
+# versione 2.20 by m750 at smartphonetab.net
 # lettura conf da file
 
 if [ `id -u` != 0 ] ; then
@@ -55,11 +55,28 @@ ledi=18
 #imposta colore LED: $verde o $rosso o $blu
 ledc=$led$coloreled
 
+
 if [ $start == 1 ] 
+
+if [ $led_r == 1 ]
+		then
+		   echo 2 > $rosso/led_current ; echo 0 > $rosso/brightness
+fi
+if [ $led_g == 1 ]
+		then
+		   echo 2 > $verde/led_current ; echo 0  > $verde/brightness
+fi
+if [ $led_b == 1 ]
+		then
+		   echo 2 > $blu/led_current ; echo 0 > $blu/brightness
+fi
+
 then
    dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"savecpu: is running"
 fi
 
+sleep 2
+
 while [ $start == 1 ]
 do
   #echo "riduci : " $riduci
@@ -67,8 +84,8 @@ do
   #echo $minima
   #echo $massima
   #temperatura=`cat /sys/class/power_supply/bq27200-0/temp`
-  temperatura=`cat /sys/devices/platform/omap34xx_temp/temp1_input | awk '{ sub(/-/,""); print $1+10}`
-  #echo "temp: " $temperatura
+  temperatura=`cat /sys/devices/platform/omap34xx_temp/temp1_input | awk '{ sub(/-/,""); print $1+7}`
+  echo "temp: " $temperatura
 
 # v47
 #  lunghezza=${#temperatura}
@@ -176,4 +193,6 @@ exit 0
 
 
 
+#
+
 #
